@@ -9,7 +9,7 @@ import tdcsm
 
 class coa():
 
-    version = "0.2.0.5"
+    version = "0.2.0.6"
     debug = False
 
     entryvars = {}
@@ -40,13 +40,14 @@ class coa():
         for name, default in kwargs.items():
             self.defaults[name] = default
         if 'approot'  not in self.defaults: self.defaults['approot']  = os.getcwd()
+        self.approot = self.defaults['approot']
         if 'config'   not in self.defaults: self.defaults['config']   = 'config.yaml'
         if 'systems'  not in self.defaults: self.defaults['systems']  = 'source_systems.yaml'
         if 'filesets' not in self.defaults: self.defaults['filesets'] = '%s%sfilesets.yaml' %('1_download', os.sep)
         if 'secrets'  not in self.defaults: self.defaults['secrets']  = self.first_file_that_exists(
-                                     os.path.join(self.defaults['approot'], '..','!secrets.yaml')
-                                    ,os.path.join(self.defaults['approot'], '..', 'secrets.yaml')
-                                    ,os.path.join(self.defaults['approot'], 'secrets.yaml'))
+                                                                         os.path.join('..','!secrets.yaml')
+                                                                        ,os.path.join('..', 'secrets.yaml')
+                                                                        ,os.path.join('secrets.yaml'))
         self.defaults['secrets'] = self.defaults['secrets'].replace(self.defaults['approot']+os.sep,'')
         for name, default in self.defaults.items():
             if name not in self.entryvars: self.entryvars[name] = StringVar()
@@ -179,7 +180,7 @@ class coa():
 
     def first_file_that_exists(self, *args):
         for file in args:
-            if os.path.isfile(file): return file
+            if os.path.isfile(os.path.join(self.approot, file)): return file
         return ''
 
     def print_dict(self, dict2print={}, lvl=0):
@@ -397,7 +398,7 @@ class coa():
             # build and execute subprocess
             cmd = []
             cmd.append("from tdcsm.tdcoa import tdcoa;")
-            cmd.append("c=tdcoa(approot='%s'," %self.entryvar('approot').replace('\\','\\\\'))
+            cmd.append("c=tdcoa(approot='%s'," %self.entryvar('approot'))
             cmd.append("config='%s',"   %self.entryvar('config'))
             cmd.append("systems='%s',"  %self.entryvar('systems'))
             cmd.append("secrets='%s');" %self.entryvar('secrets'))
@@ -406,8 +407,12 @@ class coa():
             if coacmd[-1:] != ')': coacmd = '%s()' %coacmd
             cmd.append(coacmd)
             cmd = ' '.join(cmd)
+            if 'gui_python_call' in self.coa.settings:
+                pycall = self.coa.settings['gui_python_call']
+            else:
+                pycall = 'python'
             print(cmd)
-            os.system('python -c "%s"' %cmd)
+            os.system('%s -c "%s"' %(pycall, cmd))
 
     def button_click(self, name='', **kwargs):
         print('button clicked',  name)
@@ -440,14 +445,14 @@ class coa():
         elif name == 'prepare_sql':
             self.coa.prepare_sql()
         elif name == 'execute_run':
-            # self.systems_save2disk()
+            self.systems_save2disk()
             self.run_external('execute_run')
             self.upload_get_lastrun_folder()
             #self.coa.execute_run()
         elif name == 'make_customer_files':
             self.coa.make_customer_files()
         elif name == 'upload_to_transcend':
-            # self.systems_save2disk()
+            self.systems_save2disk()
             self.run_external('upload_to_transcend')
             #self.coa.execute_run()
         elif name == 'last_output_folder':
@@ -583,6 +588,10 @@ class coa():
 
 
         #-------------- RUN!!!
+        print('approot: ' + self.entryvar('approot') )
+        print('config:  ' + self.entryvar('config') )
+        print('systems: ' + self.entryvar('systems') )
+        print('secrets: ' + self.entryvar('secrets') )
         self.coa = tdcoa(approot = self.entryvar('approot'), secrets = self.entryvar('secrets'))
         # self.systems_readfromdisk()
         self.button_click('tv_systems_left') # this 'click' will refresh both left and right treeviews
@@ -590,8 +599,8 @@ class coa():
         self.upload_get_lastrun_folder()
 
         # update our secrets file if default was different than coa.settings value (chicken/egg problem)
-        secrets_from_settings = os.path.join(self.coa.approot, self.coa.settings['secrets'])
-        secrets_from_default = self.entryvars['secrets'].get()
+        secrets_from_settings = self.coa.settings['secrets']
+        secrets_from_default =  self.entryvars['secrets'].get()
         if secrets_from_default != secrets_from_settings:
             self.entryvars['secrets'].set(self.first_file_that_exists(secrets_from_settings, secrets_from_default))
             self.coa.secrets = self.entryvars['secrets'].get()
